@@ -43,6 +43,7 @@ class FeaturePermissionBar;
 class KUrlLabel;
 class WebEngineBrowserExtension;
 class WebEngineWallet;
+class WebEngineErrorSchemeHandler;
 
 /**
  * A KPart wrapper for the QtWebEngine's browser rendering engine.
@@ -150,6 +151,9 @@ private Q_SLOTS:
 private:
     WebEnginePage* page();
     const WebEnginePage* page() const;
+    
+    void attemptInstallKIOSchemeHandler(const QUrl &url);
+    
     void initActions();
     void updateActions();
     void addWalletStatusBarIcon();
